# (C) Copyright 1996-2016 ECMWF.
#
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
# In applying this licence, ECMWF does not waive the privileges and immunities
# granted to it by virtue of its status as an intergovernmental organisation nor
# does it submit to any jurisdiction.


import xml.dom.minidom

xml = xml.dom.minidom.parse(
    "../src/xml/TextVisitor.xml"
)  # or xml.dom.minidom.parseString(xml_string)
pretty_xml_as_string = xml.toprettyxml()


print pretty_xml_as_string
