
/******************************  LICENSE  *******************************

 * (C) Copyright 1996-2017 ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.

 *******************************  LICENSE  *******************************/

/*! \\file Proj4GoogleAttributes.h
    \\brief Definition of Proj4Google Attributes class.

    This file is automatically generated.
    Do Not Edit!

*/

#include "MagRequest.h"
#include "Proj4GoogleWrapper.h"
#include "MagicsParameter.h"
#include "Factory.h"
#include "MagTranslator.h"
#include "MagicsGlobal.h"

using namespace magics;



Proj4GoogleWrapper::Proj4GoogleWrapper(): proj4google_(new Proj4Google())


{


	
	Proj4ProjectionWrapper::object(proj4google_);
	

}
Proj4GoogleWrapper::Proj4GoogleWrapper(Proj4Google* proj4google): proj4google_(proj4google)
{

	
	Proj4ProjectionWrapper::object(proj4google_);
	
}

Proj4GoogleWrapper::~Proj4GoogleWrapper()
{

}

void Proj4GoogleWrapper::set(const MagRequest& request)
{

	

	Proj4ProjectionWrapper::set(request);
	

	
	
}

void Proj4GoogleWrapper::print(ostream& out)  const
{
	out << "Proj4GoogleWrapper[]";
}


